Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(330)

Unified Diff: components/cronet/ios/Cronet.h

Issue 2465303002: [cronet] make startNetLogToFile write to correct file (Closed)
Patch Set: sync Created 3 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | components/cronet/ios/Cronet.mm » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: components/cronet/ios/Cronet.h
diff --git a/components/cronet/ios/Cronet.h b/components/cronet/ios/Cronet.h
index ba3dd7dc13b4858abe0093cd512997ab953f4bb6..446cec1557913c9abe6c469fe80ea1bef74eb36d 100644
--- a/components/cronet/ios/Cronet.h
+++ b/components/cronet/ios/Cronet.h
@@ -79,12 +79,16 @@ GRPC_SUPPORT_EXPORT
// This method must be called after |start|.
+ (void)installIntoSessionConfiguration:(NSURLSessionConfiguration*)config;
-// Starts net-internals logging to a file named |fileName| in the application
-// temporary directory. |fileName| must not be empty. Log level is determined
-// by |logBytes| - if YES then LOG_ALL otherwise LOG_ALL_BUT_BYTES. If the file
-// exists it is truncated before starting. If actively logging the call is
-// ignored.
-+ (void)startNetLogToFile:(NSString*)fileName logBytes:(BOOL)logBytes;
+// Returns the absolute path that startNetLogToFile:fileName will actually
+// write to.
++ (NSString*)getNetLogPathForFile:(NSString*)fileName;
+
+// Starts net-internals logging to a file named |fileName|. Where fileName is
+// relative to the application documents directory. |fileName| must not be
+// empty. Log level is determined by |logBytes| - if YES then LOG_ALL otherwise
+// LOG_ALL_BUT_BYTES. If the file exists it is truncated before starting. If
+// actively logging the call is ignored.
++ (BOOL)startNetLogToFile:(NSString*)fileName logBytes:(BOOL)logBytes;
// Stop net-internals logging and flush file to disk. If a logging session is
// not in progress this call is ignored.
« no previous file with comments | « no previous file | components/cronet/ios/Cronet.mm » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698